pub struct FastSerializer;Expand description
Zero-Allocation Serializer Helper
Implementations
Sourceimpl FastSerializer
impl FastSerializer
Sourcepub fn append_u64(buf: &mut Vec<u8>, val: u64)
pub fn append_u64(buf: &mut Vec<u8>, val: u64)
Appends a u64 integer to a buffer using itoa without allocating a String.
Sourcepub fn append_f64(buf: &mut Vec<u8>, val: f64)
pub fn append_f64(buf: &mut Vec<u8>, val: f64)
Appends an f64 float to a buffer using ryu without allocating a String.