pub enum LogFormat {
Show 14 variants
CLF,
JSON,
CEF,
ELF,
W3C,
GELF,
ApacheAccessLog,
Logstash,
Log4jXML,
NDJSON,
MCP,
OTLP,
Logfmt,
ECS,
}Expand description
LogFormat is an enum representing the different structured log formats supported by the RLG library.
Variants
CLF
Common Log Format (CLF)
JSON
JavaScript Object Notation (JSON)
CEF
Common Event Format (CEF)
ELF
Extended Log Format (ELF)
W3C
W3C Extended Log Format (W3C)
GELF
Graylog Extended Log Format (GELF)
ApacheAccessLog
Apache Access Log Format
Logstash
Logstash Format
Log4jXML
Log4j XML Format
NDJSON
Network Data JSON (NDJSON)
MCP
Model Context Protocol (MCP) - AI Native
OTLP
OpenTelemetry Logging (OTLP) - AI Native
Logfmt
Logfmt (key=value)
ECS
Elastic Common Schema (ECS)
Implementations
Sourceimpl LogFormat
impl LogFormat
Sourcepub fn validate(&self, entry: &str) -> bool
pub fn validate(&self, entry: &str) -> bool
Validates a log entry against the current format.
Examples
use rlg::log_format::LogFormat;
let is_valid = LogFormat::CLF.validate("127.0.0.1 - - [10/Oct/2000:13:55:36 -0700] \"GET /apache_pb.gif HTTP/1.0\" 200 2326");
assert!(is_valid);Sourcepub fn format_log(&self, entry: &str) -> RlgResult<String>
pub fn format_log(&self, entry: &str) -> RlgResult<String>
Formats a log entry according to the log format.
Errors
This function returns an error if the log entry is not valid JSON for JSON-based formats.
Panics
This function does not panic under normal usage. The internal expect guards
a serde_json::to_string_pretty call on a successfully parsed Value, which
can only fail on out-of-memory conditions.
Examples
use rlg::log_format::LogFormat;
let formatted_log = LogFormat::CLF.format_log("127.0.0.1 - - [10/Oct/2000:13:55:36 -0700] \"GET /apache_pb.gif HTTP/1.0\" 200 2326").unwrap();Trait Implementations
Sourceimpl<'de> Deserialize<'de> for LogFormat
impl<'de> Deserialize<'de> for LogFormat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
impl Copy for LogFormat
impl Eq for LogFormat
impl StructuralPartialEq for LogFormat