is_file_writable

Function is_file_writable 

pub async fn is_file_writable(path: &Path) -> RlgResult<bool>
Checks if a file exists and is writable.

Arguments

  • path - A reference to a Path that holds the file path to check.

Returns

A RlgResult<bool> which is Ok(true) if the file exists and is writable, Ok(false) otherwise, or an error if the operation fails.

Errors

This function returns an error if the file metadata cannot be read.

Examples

use rlg::utils::is_file_writable;
use std::path::Path;

#[tokio::main]
async fn main() -> rlg::error::RlgResult<()> {
    let path = Path::new("example.log");
    let is_writable = is_file_writable(&path).await?;
    println!("Is file writable: {}", is_writable);
    Ok(())
}