pub enum LogLevel {
ALL,
DEBUG,
DISABLED,
ERROR,
FATAL,
INFO,
NONE,
TRACE,
VERBOSE,
WARNING,
}Expand description
An enumeration of the different levels that a log message can have. Each variant of the enumeration represents a different level of importance.
Variants
ALL
The log level is set to all.
DEBUG
The log level is set to debug.
DISABLED
The log level is set to disabled.
ERROR
The log level is set to error.
FATAL
The log level is set to fatal.
INFO
The log level is set to info.
NONE
The log level is set to none.
TRACE
The log level is set to trace.
VERBOSE
The log level is set to verbose.
WARNING
The log level is set to warning.